# Create your own workflow and product

To cap off this workshop we will create a new product and workflows by using the built in tools that the Workflow
Orchestrator provides the user. In this scenario you will create a product that is very similar to the provided
L2VPN product, but constrained to two interfaces. In other words a L2 Point-to-Point circuit.

## L2 Point-to-Point model
{{ external_markdown('https://raw.githubusercontent.com/workfloworchestrator/orchestrator-core/main/docs/architecture/product_modelling/l2_point_to_point.md',
'') }}
